@@ -1,4 +1,4 @@
-/* $MirOS: contrib/code/jupp/syntax.c,v 1.6 2011/07/02 16:26:10 tg Exp $ */
+/* $MirOS: contrib/code/jupp/syntax.c,v 1.8 2012/07/18 17:02:56 tg Exp $ */
 /*
  *	Syntax highlighting DFA interpreter
  *	Copyright
@@ -77,8 +77,11 @@ int parse(struct high_syntax *syntax,P *line,int state)
 				h = cmd->new_state;
 			}
 			/* Recolor if necessary */
-			for(x=cmd->recolor;x<0;++x)
-				attr[x] = h -> color;
+			x = cmd->recolor;
+			while (&attr[x] < attr_buf)
+				++x;
+			while (x < 0)
+				attr[x++] = h->color;
 
 			/* Start buffering? */
 			if (cmd->start_buffering) {
@@ -208,7 +211,7 @@ struct high_syntax *load_dfa(unsigned char *name)
 	syntax->nstates = 0;
 	syntax->color = 0;
 	syntax->states = malloc(sizeof(struct high_state *)*(syntax->szstates=64));
-	syntax->sync_lines = 50;
+	syntax->sync_lines = 120;
 	syntax->default_cmd.noeat = 0;
 	syntax->default_cmd.recolor = 0;
 	syntax->default_cmd.start_buffering = 0;
