@@ -1,4 +1,4 @@
-/* $MirOS: contrib/code/jupp/termcap.c,v 1.4 2011/07/16 21:57:57 tg Exp $ */
+/* $MirOS: contrib/code/jupp/termcap.c,v 1.6 2012/06/08 17:05:12 tg Exp $ */
 /*
  *	TERMCAP/TERMINFO database interface
  *	Copyright
@@ -121,10 +121,10 @@ static unsigned char *lfind(unsigned char *s, int pos, FILE *fd, unsigned char *
 
 /* Lookup termcap entry in index */
 
-static long findidx(FILE *file, unsigned char *name)
+static off_t findidx(FILE *file, unsigned char *name)
 {
 	unsigned char buf[80];
-	long addr = 0;
+	off_t addr = 0;
 
 	while (fgets((char *)buf, 80, file)) {
 		int x = 0, flg = 0, c, y, z;
@@ -153,7 +153,7 @@ CAP *getcap(unsigned char *name, unsigned int baud, void (*out) (unsigned char *
 {
 	CAP *cap;
 	FILE *f, *f1;
-	long idx;
+	off_t idx;
 	int x, y, c, z, ti;
 	unsigned char *tp, *pp, *qq, *namebuf, **npbuf, *idxname;
 	int sortsiz;
@@ -248,7 +248,7 @@ CAP *getcap(unsigned char *name, unsigned int baud, void (*out) (unsigned char *
 		fclose(f);
 	}
 	vsrm(idxname);
-	fseek(f1, idx, 0);
+	fseeko(f1, idx, 0);
 	cap->tbuf = lfind(cap->tbuf, ti, f1, name);
 	fclose(f1);
 	if (sLEN(cap->tbuf) == ti)
@@ -713,69 +713,3 @@ unsigned char *tcompile(CAP *cap, unsigned char *s, int a0, int a1, int a2, int
 	cap->div = divider;
 	return ssp;
 }
-
-/* Old termcap compatibility (not to be used when TERMINFO is set) */
-#ifdef junk
-short ospeed;			/* Output speed */
-unsigned char PC, *UP, *BC;		/* Unused */
-static CAP *latest;		/* CAP entry to use */
-
-static void stupid(ptr, c)
-void (*ptr) ();
-unsigned char c;
-{
-	ptr(c);
-}
-
-int tgetent(buf, name)
-unsigned char *buf, *name;
-{
-	latest = getcap(name, 9600, stupid, NULL);
-	if (latest)
-		return 1;
-	else
-		return -1;
-}
-
-int tgetflag(name)
-unsigned char *name;
-{
-	return getflag(latest, name);
-}
-
-int tgetnum(name)
-unsigned char *name;
-{
-	return getnum(latest, name);
-}
-
-unsigned char *tgetstr(name)
-unsigned char *name;
-{
-	return jgetstr(latest, name);
-}
-
-static int latestx, latesty;
-
-unsigned char *tgoto(str, x, y)
-unsigned char *str;
-int x, y;
-{
-	latestx = x;
-	latesty = y;
-	return str;
-}
-
-void tputs(str, l, out)
-unsigned char *str;
-int l;
-void (*out) ();
-{
-	latest->outptr = (void *) out;
-	if (latest->baud != ospeed) {
-		latest->baud = ospeed;
-		latest->div = 100000 / ospeed;
-	}
-	texec(latest, str, l, latesty, latestx);
-}
-#endif
