@@ -1,4 +1,4 @@
-/* $MirOS: contrib/code/jupp/tty.c,v 1.15 2011/07/16 21:57:57 tg Exp $ */
+/* $MirOS: contrib/code/jupp/tty.c,v 1.17 2012/06/08 16:55:28 tg Exp $ */
 /*
  *	UNIX Tty and Process interface
  *	Copyright
@@ -796,11 +796,6 @@ void ttsusp(void)
 	ttclsn();
 	fprintf(stderr, "You have suspended the program.  Type 'fg' to return\n");
 	kill(0, SIGTSTP);
-#ifdef junk
-	/* Hmmm... this should not have been necessary */
-	if (ackkbd != -1)
-		kill(kbdpid, SIGCONT);
-#endif
 	if (omode)
 		ttopnn();
 	if (ackkbd!= -1)
@@ -1141,10 +1136,13 @@ MPX *mpxmk(int *ptyfd, unsigned char *cmd, unsigned char **args, void (*func) (/
 #endif
 
 				/* Open stdout, stderr */
-				dup(x);
-				dup(x);	/* Standard output, standard error */
-				/* (yes, stdin, stdout, and stderr must all be open for reading and
-				 * writing.  On some systems the shell assumes this */
+				if (dup(x)) {}	/* standard output */
+				if (dup(x)) {}	/* standard error */
+				/*
+				 * yes, stdin, stdout, and stderr must
+				 * all be open for reading and writing.
+				 * On some systems the shell assumes this.
+				 */
 #endif
 
 				/* We could probably have a special TTY set-up for JOE, but for now
