@@ -1,22 +1,4 @@
-/* $MirOS: contrib/code/jupp/types.h,v 1.6 2011/07/03 00:35:05 tg Exp $ */
-
-/*-
- * This file is part of JUPP, a variant of Joe's Own Editor.
- *
- * JUPP is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 1 (February 1989), as shown
- * in the file COPYING in the JUPP source distribution.
- *
- * This work is provided "AS IS" and WITHOUT WARRANTY of any kind, to
- * the utmost extent permitted by applicable law, neither express nor
- * implied; without malicious intent or gross negligence. In no event
- * may a licensor, author or contributor be held liable for indirect,
- * direct, other damage, loss, or other issues arising in any way out
- * of dealing in the work, even if advised of the possibility of such
- * damage or existence of a defect, except proven that it results out
- * of said person's immediate fault when using the work as intended.
- */
+/* $MirOS: contrib/code/jupp/types.h,v 1.8 2012/06/08 16:55:28 tg Exp $ */
 
 #ifndef _JOE_TYPES_H
 #define _JOE_TYPES_H
@@ -45,16 +27,6 @@
 #define TYPEMENU	0x0800
 #define TYPEQW		0x1000
 
-#ifdef junk					/* These are now defined in config.h */
-
-/* Minimum page size for MS-DOS is 128 (for 32K vheaders table) or 256 (for
- * 64K vheaders table) */
-#define PGSIZE 512		/* Page size in bytes (Must be power of 2) */
-#define LPGSIZE 9		/* LOG base 2 of PGSIZE */
-#define ILIMIT (PGSIZE*128L)	/* Max amount to buffer */
-#define HTSIZE 128		/* Entries in hash table.  Must be pwr of 2 */
-#endif
-
 
 typedef struct header H;
 typedef struct buffer B;
